export declare type Category = "titlepiece" | "headline" | "body" | "textSans";
export declare type LineHeight = "tight" | "regular" | "loose";
export declare type FontWeight = "light" | "regular" | "medium" | "bold";
export declare type FontWeightDefinition = {
    hasItalic: boolean;
};
export declare type TitlepieceSizes = "small" | "medium" | "large";
export declare type HeadlineSizes = "xxxsmall" | "xxsmall" | "xsmall" | "small" | "medium" | "large" | "xlarge";
export declare type BodySizes = "small" | "medium";
export declare type TextSansSizes = "xsmall" | "small" | "medium" | "large" | "xlarge";
export declare type TypographyStyles = {
    fontFamily: string;
    fontSize: string;
    lineHeight: number;
    fontWeight?: number;
    fontStyle?: string;
};
export declare type Fs = (category: Category, level: string, { lineHeight, fontWeight, italic, }: {
    lineHeight: LineHeight;
    fontWeight: FontWeight;
    italic: boolean;
}) => TypographyStyles;
export interface FontScaleArgs {
    lineHeight?: LineHeight;
    fontWeight?: FontWeight;
    italic?: boolean;
}
export declare const fontSizesRem: number[];
export declare const titlepieceSizes: {
    [key in TitlepieceSizes]: number;
};
export declare const headlineSizes: {
    [key in HeadlineSizes]: number;
};
export declare const bodySizes: {
    [key in BodySizes]: number;
};
export declare const textSansSizes: {
    [key in TextSansSizes]: number;
};
export declare const fontSizeMapping: {
    [cat in Category]: {
        [level in string]: number;
    };
};
export declare const fontMapping: {
    [cat in Category]: string;
};
export declare const lineHeightMapping: {
    [lineHight in LineHeight]: number;
};
export declare const fontWeightMapping: {
    [fontWeight in FontWeight]: number;
};
export declare const availableFonts: {
    [cat in Category]: {
        [fontWeight in FontWeight]?: FontWeightDefinition;
    };
};
